==> nextcloud-app-calendar-1.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/lt_LT.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendorius",
    "Too many redirects. Aborting ..." : "Per daug nukreipimų. Nutraukiama ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Nutolęs serveris neleido prisijungti prie kalendoriaus (HTTP {%s} klaida)",
    "Error connecting to remote server" : "Klaida, jungiantis prie nuotolinio serverio",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Klaida gaunant informaciją iš nutolusio serverio. Tai galimai gali būti susiję su sertifikatų neatitikimu",
    "Error requesting resource on remote server" : "Klaida gaunant informaciją iš nutolusio serverio",
    "%s has published the calendar \"%s\"" : "%s buvo paskelbta kalendoriuje \"%s\"",
    "Individual" : "Individualus",
    "Group" : "Grupė",
    "Resource" : "Išteklis",
    "Room" : "Kambarys",
    "Unknown" : "Nežinomas",
    "Required" : "Privaloma",
    "Optional" : "Nebūtina",
    "Does not attend" : "Nedalyvauja",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jūsų laiko juosta ({tz}) nežinoma, bus naudojama UTC laiko juosta",
    "Please create a calendar first." : "Prašome, iš pradžių, sukurti kalendorių.",
    "New event" : "Naujas įvykis",
    "CalDAV address for clients" : "CalDAV adresas klientams",
    "Error saving WebCal-calendar" : "Klaida, įrašant WebCal kalendorių",
    "WebDAV address for subscriptions" : "WebDAV adresas prenumeratoms",
    "EMail has been sent." : "El. laiškas išsiųstas.",
    "There was an issue while sending your EMail." : "Klaida siunčiant el. laišką.",
    "group" : "grupė",
    "Details" : "Išsamiau",
    "Attendees" : "Dalyviai",
    "Reminders" : "Priminimai",
    "Repeating" : "Pasikartojimas",
    "When shared show full event" : "Dalijantis rodyti pilną įvykį",
    "When shared show only busy" : "Dalijantis rodyti kaip užimtą",
    "When shared hide this event" : "Dalijantis nerodyti šio įvykio",
    "Confirmed" : "Patvirtintas",
    "Cancelled" : "Atšauktas",
    "Please add a title!" : "Pridėkite pavadinimą!",
    "Please select a calendar!" : "Pasirinkite kalendorių!",
    "Global" : "Globalus",
    "None" : "Nieko",
    "Every day" : "Kas dieną",
    "Every week" : "Kas savaitę",
    "Every month" : "Kas mėnesį",
    "Every year" : "Kas metus",
    "never" : "niekada",
    "after" : "prieš",
    "How about getting started by importing some calendars?" : "Gal pradžiai norite importuoti kitus kalendorius?",
    "At time of event" : "Įvykio metu",
    "5 minutes before" : "5 minutes prieš",
    "10 minutes before" : "10 minučių prieš",
    "15 minutes before" : "15 minučių prieš",
    "30 minutes before" : "30 minučių prieš",
    "1 hour before" : "1 valandą prieš",
    "2 hours before" : "2 valandas prieš",
    "Custom" : "Kitaip",
    "Audio" : "Garsu",
    "E Mail" : "El. paštu",
    "Pop up" : "Iššokančiu langu",
    "sec" : "s",
    "min" : "min",
    "hours" : "valandos",
    "days" : "dienos",
    "week" : "savaitė",
    "before" : "prieš",
    "start" : "pradžia",
    "end" : "pabaiga",
    "Editing reminders of unknown type not supported." : "Nežinomo tipo priminimų redagavimas negalimas.",
    "Week {number} of {year}" : "{year} metų {number} savaitė ",
    "Successfully imported" : "Sėkmingai importuota",
    "Partially imported, 1 failure" : "Dalinai importuota, 1 klaida",
    "Partially imported, {n} failures" : "Dalinai importuota, {n} klaidų",
    "Audio alarm" : "Gaso pranešimas",
    "Pop-up" : "Iššokantis langas",
    "E-Mail" : "El. paštas",
    "{type} {time} before the event starts" : "{type} {time} prieš įvykio pradžią",
    "{type} {time} before the event ends" : "{type} {time} prieš įvykio pabaigą",
    "{type} {time} after the event starts" : "{type} {time} po įvykio pradžios",
    "{type} {time} after the event ends" : "{type} {time} po įvykio pabaigos",
    "{type} at the event's start" : "{type} prasidedant įvykiui",
    "{type} at the event's end" : "{type} pasibaigiant įvykiui",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} pasidalino {owner}",
    "Please enter a valid WebCal-URL" : "Prašome įvesti tinkamą WebCal adresą",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Klaida naudojant WebCal proxy. Prašome susisiekti su administratoriumi.",
    "Title of the Event" : "Įvykio pavadinimas",
    "starts" : "prasideda",
    "ends" : "baigiasi",
    "All day Event" : "Visos dienos įvykis",
    "Delete" : "Ištrinti",
    "Cancel" : "Atšaukti",
    "More ..." : "Daugiau...",
    "Create" : "Sukurti",
    "Update" : "Atnaujinti",
    "Close" : "Užverti",
    "Location" : "Vieta",
    "Description" : "Aprašymas",
    "Event status" : "Įvykio statusas",
    "Visibility when sharing" : "Matomumas dalinantis",
    "Export" : "Eksportuoti",
    "%s has published the calendar %s" : "%s paskelbė kalendorių %s",
    "Hello," : "Sveiki,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Norime Jus informuoti, kad %s paskelbė kalendorių {boldstart}%s{boldend}.",
    "Click here to access it" : "Paspauskite čia norėdami pamatyti",
    "Cheers!" : "Sveikinimai!",
    "We wanted to inform you that %s has published the calendar %s." : "Norime Jus informuoti, kad %s paskelbė kalendorių %s.",
    "Click on the link below to access it" : "Paspauskite nuorodą norėdami pamatyti",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Dėl klaidos kalendorius šiuo metu nepalaiko \"pipeline\" funkcijos.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prašome susisiekti su administratoriumi ir paprašyti išjungti \"asset-pipeline.enabled\" nustatymą.",
    "Day" : "Diena",
    "Week" : "Savaitė",
    "Month" : "Mėnuo",
    "Today" : "Šiandien",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Kai kurie kalendoriaus įvykiai yra sugadinti. Prašome patikrinti JS konsolę.",
    "Share Calendar" : "Dalintis kalendoriumi",
    "Shared" : "Dalinamasi",
    "More" : "Daugiau",
    "Edit" : "Redaguoti",
    "Link" : "Nuoroda",
    "WebCal URL" : "WebCal adresas",
    "Download" : "Atsisiųsti",
    "Share with users or groups" : "Dalintis su naudotojais arba grupėmis",
    "can edit" : "gali redaguoti",
    "Share link" : "Dalintis nuoroda",
    "Public access" : "Viešai",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send" : "Siųsti",
    "New Calendar" : "Naujas kalendorius",
    "Name" : "Pavadinimas",
    "New Subscription" : "Nauja prenumerata",
    "WebCal-URL" : "WebCal adresas",
    "Go back" : "Atgal",
    "Go forward" : "Pirmyn",
    "Edit event" : "Redaguoti įvykį",
    "Delete Event" : "Ištrinti įvykį",
    "Save Event" : "Įrašyti įvykį",
    "Time" : "Laikas",
    "Type" : "Tipas",
    "Relative" : "Santykinis",
    "Absolute" : "Absoliutus",
    "Repeat" : "Kartoti",
    "times every" : "kartų kiekvieną",
    "Add" : "Pridėti",
    "E-Mail address of attendee" : "Dalyvaujančiųjų el. pašto adresai",
    "Please add your email address in the personal settings in order to add attendees." : "Pridėkite savo el. pašto adresą norėdami pakviesti dalyvius.",
    "from" : "iš",
    "to" : "į",
    "This event's repeating rule is not supported yet." : "Šio įvykio pasikartojimo taisyklė nepalaikoma.",
    "Support for advanced rules will be added with subsequent updates." : "Papildomų taisyklių palaikymas bus pridėtas po ateinančių atnaujinimų.",
    "Reset repeating rule" : "Atstatyti pasikartojimą",
    "Repeat every ..." : "Kartoti...",
    "end repeat ..." : "nutraukti pasikartojimą...",
    "times" : "kartus",
    "Import Calendars" : "Importuoti kalendorius",
    "Import canceled" : "Importavimas atšauktas",
    "Analyzing calendar" : "Analizuojamas kalendorius",
    "The file contains objects incompatible with the selected calendar" : "Failas turi objektų kurie nėra suderinami su pasirinktu kalendoriumi",
    "New calendar" : "Naujas kalendorius",
    "File is empty" : "Failas tuščias",
    "Import scheduled" : "Importavimas suplanuotas",
    "Settings" : "Nustatymai",
    "Publish URL" : "Skelbti adresą",
    "Iframe to integrate" : "Iframe integravimas",
    "Settings & import" : "Nustatymai ir įkėlimas",
    "Skip simple event editor" : "Praleisti paprastą įvykių redaktorių",
    "Show week numbers" : "Rodyti savaičių numerius",
    "Import calendar" : "Importuoti kalendorių",
    "No Calendars selected for import" : "Nepasirinktas kalendorius importavimui",
    "Primary CalDAV address" : "Pirminis CalDAV adresas",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/lt_LT.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendorius",
    "%s has published the calendar \"%s\"" : "%s buvo paskelbta kalendoriuje \"%s\"",
    "Too many redirects. Aborting ..." : "Per daug nukreipimų. Nutraukiama ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Nutolęs serveris neleido prisijungti prie kalendoriaus (HTTP {%s} klaida)",
    "Error connecting to remote server" : "Klaida, jungiantis prie nuotolinio serverio",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Klaida gaunant informaciją iš nutolusio serverio. Tai galimai gali būti susiję su sertifikatų neatitikimu",
    "Error requesting resource on remote server" : "Klaida gaunant informaciją iš nutolusio serverio",
    "Individual" : "Individualus",
    "Group" : "Grupė",
    "Resource" : "Išteklis",
    "Room" : "Kambarys",
    "Unknown" : "Nežinomas",
    "Required" : "Privaloma",
    "Optional" : "Nebūtina",
    "Does not attend" : "Nedalyvauja",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jūsų laiko juosta ({tz}) nežinoma, bus naudojama UTC laiko juosta",
    "Please create a calendar first." : "Prašome, iš pradžių, sukurti kalendorių.",
    "New event" : "Naujas įvykis",
    "CalDAV address for clients" : "CalDAV adresas klientams",
    "Error saving WebCal-calendar" : "Klaida, įrašant WebCal kalendorių",
    "WebDAV address for subscriptions" : "WebDAV adresas prenumeratoms",
    "EMail has been sent." : "El. laiškas išsiųstas.",
    "There was an issue while sending your EMail." : "Klaida siunčiant el. laišką.",
    "group" : "grupė",
    "Details" : "Išsamiau",
    "Attendees" : "Dalyviai",
    "Reminders" : "Priminimai",
    "Repeating" : "Pasikartojimas",
    "When shared show full event" : "Bendrinant, rodyti pilną įvykį",
    "When shared show only busy" : "Bendrinant rodyti tik užimtą",
    "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
    "Confirmed" : "Patvirtintas",
    "Cancelled" : "Atsisakyta",
    "Please add a title!" : "Pridėkite pavadinimą!",
    "Please select a calendar!" : "Pasirinkite kalendorių!",
    "Global" : "Globalus",
    "None" : "Nieko",
    "Every day" : "Kas dieną",
    "Every week" : "Kas savaitę",
    "Every month" : "Kas mėnesį",
    "Every year" : "Kas metus",
    "never" : "niekada",
    "after" : "prieš",
    "How about getting started by importing some calendars?" : "Gal pradžiai norite importuoti kitus kalendorius?",
    "At time of event" : "Įvykio metu",
    "5 minutes before" : "5 minutes prieš",
    "10 minutes before" : "10 minučių prieš",
    "15 minutes before" : "15 minučių prieš",
    "30 minutes before" : "30 minučių prieš",
    "1 hour before" : "1 valandą prieš",
    "2 hours before" : "2 valandas prieš",
    "Custom" : "Kitaip",
    "Audio" : "Garsu",
    "E Mail" : "El. paštu",
    "Pop up" : "Iššokančiu langu",
    "sec" : "s",
    "min" : "min",
    "hours" : "valandos",
    "days" : "dienos",
    "week" : "savaitė",
    "before" : "prieš",
    "start" : "pradžia",
    "end" : "pabaiga",
    "Editing reminders of unknown type not supported." : "Nežinomo tipo priminimų redagavimas negalimas.",
    "Week {number} of {year}" : "{year} metų {number} savaitė ",
    "Successfully imported" : "Sėkmingai importuota",
    "Partially imported, 1 failure" : "Dalinai importuota, 1 klaida",
    "Partially imported, {n} failures" : "Dalinai importuota, {n} klaidų",
    "Audio alarm" : "Gaso pranešimas",
    "Pop-up" : "Iššokantis langas",
    "E-Mail" : "El. paštas",
    "{type} {time} before the event starts" : "{type} {time} prieš įvykio pradžią",
    "{type} {time} before the event ends" : "{type} {time} prieš įvykio pabaigą",
    "{type} {time} after the event starts" : "{type} {time} po įvykio pradžios",
    "{type} {time} after the event ends" : "{type} {time} po įvykio pabaigos",
    "{type} at the event's start" : "{type} prasidedant įvykiui",
    "{type} at the event's end" : "{type} pasibaigiant įvykiui",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} pasidalino {owner}",
    "Please enter a valid WebCal-URL" : "Prašome įvesti tinkamą WebCal adresą",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Klaida naudojant WebCal proxy. Prašome susisiekti su administratoriumi.",
    "Title of the Event" : "Įvykio pavadinimas",
    "starts" : "prasideda",
    "ends" : "baigiasi",
    "All day Event" : "Visos dienos įvykis",
    "Delete" : "Ištrinti",
    "Cancel" : "Atsisakyti",
    "More ..." : "Daugiau...",
    "Create" : "Sukurti",
    "Update" : "Atnaujinti",
    "Close" : "Užverti",
    "Location" : "Vieta",
    "Description" : "Aprašymas",
    "Event status" : "Įvykio statusas",
    "Visibility when sharing" : "Matomumas dalinantis",
    "Export" : "Eksportuoti",
    "%s has published the calendar %s" : "%s paskelbė kalendorių %s",
    "Hello," : "Sveiki,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Norime Jus informuoti, kad %s paskelbė kalendorių {boldstart}%s{boldend}.",
    "Click here to access it" : "Paspauskite čia norėdami pamatyti",
    "Cheers!" : "Sveikinimai!",
    "We wanted to inform you that %s has published the calendar %s." : "Norime Jus informuoti, kad %s paskelbė kalendorių %s.",
    "Click on the link below to access it" : "Paspauskite nuorodą norėdami pamatyti",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Dėl klaidos kalendorius šiuo metu nepalaiko \"pipeline\" funkcijos.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prašome susisiekti su administratoriumi ir paprašyti išjungti \"asset-pipeline.enabled\" nustatymą.",
    "Day" : "Diena",
    "Week" : "Savaitė",
    "Month" : "Mėnuo",
    "Today" : "Šiandien",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Kai kurie šio kalendoriaus įvykiai yra sugadinti. Prašome patikrinti JS pultą.",
    "Share Calendar" : "Dalintis kalendoriumi",
    "Shared" : "Dalinamasi",
    "More" : "Daugiau",
    "Edit" : "Redaguoti",
    "Link" : "Nuoroda",
    "iCal link" : "iCal nuoroda",
    "Download" : "Atsisiųsti",
    "Share with users or groups" : "Dalintis su naudotojais arba grupėmis",
    "can edit" : "gali redaguoti",
    "Share link" : "Dalintis nuoroda",
    "Public access" : "Viešai",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send" : "Siųsti",
    "New Calendar" : "Naujas kalendorius",
    "Name" : "Pavadinimas",
    "New Subscription" : "Nauja prenumerata",
    "Go back" : "Atgal",
    "Go forward" : "Pirmyn",
    "Edit event" : "Redaguoti įvykį",
    "Delete Event" : "Ištrinti įvykį",
    "Save Event" : "Įrašyti įvykį",
    "Time" : "Laikas",
    "Type" : "Tipas",
    "Relative" : "Santykinis",
    "Absolute" : "Absoliutus",
    "Repeat" : "Kartoti",
    "times every" : "kartų kiekvieną",
    "Add" : "Pridėti",
    "E-Mail address of attendee" : "Dalyvaujančiųjų el. pašto adresai",
    "Please add your email address in the personal settings in order to add attendees." : "Pridėkite savo el. pašto adresą norėdami pakviesti dalyvius.",
    "from" : "iš",
    "to" : "į",
    "This event's repeating rule is not supported yet." : "Šio įvykio pasikartojimo taisyklė nepalaikoma.",
    "Support for advanced rules will be added with subsequent updates." : "Papildomų taisyklių palaikymas bus pridėtas po ateinančių atnaujinimų.",
    "Reset repeating rule" : "Atstatyti pasikartojimą",
    "Repeat every ..." : "Kartoti...",
    "end repeat ..." : "nutraukti pasikartojimą...",
    "times" : "kartus",
    "Import Calendars" : "Importuoti kalendorius",
    "Import canceled" : "Importavimo atsisakyta",
    "Analyzing calendar" : "Analizuojamas kalendorius",
    "The file contains objects incompatible with the selected calendar" : "Failas turi objektų kurie nėra suderinami su pasirinktu kalendoriumi",
    "New calendar" : "Naujas kalendorius",
    "File is empty" : "Failas tuščias",
    "Import scheduled" : "Importavimas suplanuotas",
    "Subscribe & embed" : "Prenumeruoti ir įdėti",
    "Publish URL" : "Skelbti adresą",
    "Iframe to integrate" : "Iframe integravimas",
    "Settings & import" : "Nustatymai ir importavimas",
    "Skip simple event editor" : "Praleisti paprastą įvykių redaktorių",
    "Show week numbers" : "Rodyti savaičių numerius",
    "Import calendar" : "Importuoti kalendorių",
    "No Calendars selected for import" : "Nepasirinktas kalendorius importavimui",
    "Primary CalDAV address" : "Pirminis CalDAV adresas",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
